@@ -1,5 +1,5 @@
 /* example5.c --- Example TLD checking.
- * Copyright (C) 2004, 2005, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -52,7 +52,7 @@
  */
 
 int
-main (int argc, char *argv[])
+main (void)
 {
   char buf[BUFSIZ];
   char *p;
