@@ -22,6 +22,18 @@
 #ifndef PR29_H
 # define PR29_H
 
+# ifndef IDNAPI
+#  if defined LIBIDN_BUILDING && defined HAVE_VISIBILITY && HAVE_VISIBILITY
+#   define IDNAPI __attribute__((__visibility__("default")))
+#  elif defined LIBIDN_BUILDING && defined _MSC_VER && ! defined LIBIDN_STATIC
+#   define IDNAPI __declspec(dllexport)
+#  elif defined _MSC_VER && ! defined LIBIDN_STATIC
+#   define IDNAPI __declspec(dllimport)
+#  else
+#   define IDNAPI
+#  endif
+# endif
+
 # ifdef __cplusplus
 extern "C"
 {
@@ -41,11 +53,11 @@ extern "C"
     PR29_STRINGPREP_ERROR = 2	/* Charset conversion failed (p29_8*). */
   } Pr29_rc;
 
-  extern const char *pr29_strerror (Pr29_rc rc);
+  extern IDNAPI const char *pr29_strerror (Pr29_rc rc);
 
-  extern int pr29_4 (const uint32_t * in, size_t len);
-  extern int pr29_4z (const uint32_t * in);
-  extern int pr29_8z (const char *in);
+  extern IDNAPI int pr29_4 (const uint32_t * in, size_t len);
+  extern IDNAPI int pr29_4z (const uint32_t * in);
+  extern IDNAPI int pr29_8z (const char *in);
 
 # ifdef __cplusplus
 }
