@@ -1,5 +1,5 @@
 /* tst_strerror.c --- Self tests for *_strerror().
- * Copyright (C) 2004, 2005, 2006, 2007, 2008  Simon Josefsson.
+ * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -111,7 +111,7 @@ doit (void)
 
   {
     size_t i;
-    const char *p, *last_p = NULL;
+    const char *last_p = NULL;
 
     for (i = 0;; i++)
       {
@@ -133,7 +133,7 @@ doit (void)
 
   {
     size_t i;
-    const char *p, *last_p = NULL;
+    const char *last_p = NULL;
 
     for (i = 0;; i++)
       {
@@ -148,7 +148,7 @@ doit (void)
 
   {
     size_t i;
-    const char *p, *last_p = NULL;
+    const char *last_p = NULL;
 
     for (i = 0;; i++)
       {
@@ -163,7 +163,7 @@ doit (void)
 
   {
     size_t i;
-    const char *p, *last_p = NULL;
+    const char *last_p = NULL;
 
     for (i = 0;; i++)
       {
@@ -190,7 +190,7 @@ doit (void)
 
   {
     size_t i;
-    const char *p, *last_p = NULL;
+    const char *last_p = NULL;
 
     for (i = 0;; i++)
       {
